@@ -3,7 +3,7 @@ use 5.012;
 use warnings;
 use strict;
 
-our $VERSION = '1.44_01';
+our $VERSION = '1.44_02';
 
 use Carp;
 use Data::Compare;
@@ -11,11 +11,12 @@ use Data::Dumper;
 use Devel::Examine::Subs::Engine;
 use Devel::Examine::Subs::Preprocessor;
 use Devel::Examine::Subs::Prefilter;
+use File::Basename;
 use File::Copy;
 use File::Edit::Portable;
 use File::Find;
 use PPI;
-use Symbol;
+use Symbol qw(delete_package);
 
 BEGIN {
 
@@ -248,7 +249,7 @@ sub remove {
 }
 
 #
-# publicly available private methods
+# publicly available semi-private methods
 #
 
 sub add_functionality {
@@ -700,7 +701,11 @@ sub _read_file {
 
     return if ! $file;
 
-    copy $file, "$file.bak" or croak $!;
+    my $basename = basename($file);
+    my $bak = "$basename.bak";
+
+    copy $file, $bak
+      or croak "can't create backup copy of file $file!";
 
     $self->{rw} = File::Edit::Portable->new;
 
@@ -736,6 +741,11 @@ sub _write_file {
         croak $@;
     }
 }
+
+#
+# private methods for core phases
+#
+
 sub _core {
 
     trace() if $ENV{TRACE};
@@ -844,8 +854,69 @@ sub _core {
 
     return $subs;
 }
-sub _proc {
+sub _pre_proc {
     
+    trace() if $ENV{TRACE};
+
+    my $self = shift;
+    my $p = shift;
+    my $subs = shift;
+
+    my $pre_proc = $self->{params}{pre_proc};
+
+    if (not $pre_proc or $pre_proc eq ''){
+        return $subs;
+    }
+   
+    # tell _core() to return directly from the pre_processor 
+    # if necessary, and bypass pre_filter and engine
+
+    if ($pre_proc eq 'module'){
+       $self->{params}{pre_proc_return} = 1;
+    }
+
+    my $cref;
+    
+    if (not ref($pre_proc) eq 'CODE'){
+        my $pre_proc_module = $self->{namespace} . "::Preprocessor";
+        my $compiler = $pre_proc_module->new;
+
+        if (! $compiler->exists($pre_proc)){
+            croak "Devel::Examine::Subs::_pre_proc() speaking...\n\n" .
+                  "pre_processor '$pre_proc' is not implemented.\n";
+        }
+
+        eval {
+            $cref = $compiler->{pre_procs}{$pre_proc}->();
+        };
+        
+        if ($@){
+            $@ = "\n[Devel::Examine::Subs speaking] " .
+                  "dispatch table in Devel::Examine::Subs::Preprocessor " .
+                  "has a mistyped function as a value, but the key is ok\n\n"
+            . $@;
+            croak $@;
+        }
+
+    }
+
+    if (ref($pre_proc) eq 'CODE'){
+        $cref = $pre_proc;
+    }
+    
+    return $cref;
+}
+sub _proc {
+   
+    # this method is the core data collection/manipulation
+    # routine (aka the 'Processor phase') for all of DES
+
+    # do not modify this sub
+
+    # if you want the data structure to look differently before 
+    # reaching here, use a pre_proc. If you want it different 
+    # afterwards, use a pre_filter or an engine
+
     trace() if $ENV{TRACE};
     
     my $self = shift;
@@ -915,58 +986,6 @@ sub _proc {
    
     return \%subs;
 }
-sub _pre_proc {
-    
-    trace() if $ENV{TRACE};
-
-    my $self = shift;
-    my $p = shift;
-    my $subs = shift;
-
-    my $pre_proc = $self->{params}{pre_proc};
-
-    if (not $pre_proc or $pre_proc eq ''){
-        return $subs;
-    }
-   
-    # tell _core() to return directly from the pre_processor 
-    # if necessary, and bypass pre_filter and engine
-
-    if ($pre_proc eq 'module'){
-       $self->{params}{pre_proc_return} = 1;
-    }
-
-    my $cref;
-    
-    if (not ref($pre_proc) eq 'CODE'){
-        my $pre_proc_module = $self->{namespace} . "::Preprocessor";
-        my $compiler = $pre_proc_module->new;
-
-        if (! $compiler->exists($pre_proc)){
-            croak "Devel::Examine::Subs::_pre_proc() speaking...\n\n" .
-                  "pre_processor '$pre_proc' is not implemented.\n";
-        }
-
-        eval {
-            $cref = $compiler->{pre_procs}{$pre_proc}->();
-        };
-        
-        if ($@){
-            $@ = "\n[Devel::Examine::Subs speaking] " .
-                  "dispatch table in Devel::Examine::Subs::Preprocessor " .
-                  "has a mistyped function as a value, but the key is ok\n\n"
-            . $@;
-            croak $@;
-        }
-
-    }
-
-    if (ref($pre_proc) eq 'CODE'){
-        $cref = $pre_proc;
-    }
-    
-    return $cref;
-}
 sub _pre_filter {
     
     trace() if $ENV{TRACE};
@@ -1187,19 +1206,21 @@ Inject code into sub after a search term (preserves previous line's indenting)
 
 Print out all lines in all subs that contain a search term
 
-    my $subs = $des->objects;
+    my $subs = $des->lines(search => 'this');
 
-    for my $sub (@$subs){
-    
-        my $lines_with_search_term = $sub->lines;
+    for my $sub (keys %$subs){
 
-        for (@$lines_with_search_term){
-            my ($line_num, $text) = split /:/, $_, 2;
+        print "\nSub: $sub\n";
+
+        for my $line (@{ $subs->{$sub} }){
+            my ($line_num, $text) = each %$line;
             say "Line num: $line_num";
             say "Code: $text\n";
         }
     }
 
+
+
 The structures look a bit differently when 'file' is a directory.
 You need to add one more layer of extraction.
 
@@ -1220,7 +1241,7 @@ Print all subs within each Perl file under a directory
         print join('\t', @{$files->{$file}});
     }
 
-All methods can include or exclude specific subs
+Most methods can include or exclude specific subs
 
     my $has = $des->has( include => [qw(dump private)] );
 
@@ -1240,9 +1261,7 @@ options.
 
 =head1 METHODS
 
-All public methods take their parameters as a hash (C<key =E<gt> value>).
-
-See the L<PARAMETERS> for the full list of params, and which ones 
+See the L<PARAMETERS> for the full list of params, and which ones
 are persistent across runs using the same object.
 
 
@@ -1261,7 +1280,7 @@ Only specific params are guaranteed to stay persistent throughout a run on the
 same object, and are best set in C<new()>. These parameters are C<file>,
 C<extensions>, C<cache>, C<regex>, C<copy>, C<no_indent> and C<diff>.
 
-
+Note: omit this parameter if all you'll be using is the C<module()> method.
 
 
 
@@ -1312,9 +1331,10 @@ See L<SYNOPSIS> for the structure of each object.
 
 
 
-=head2 C<module>
+=head2 C<module('Module::Name'>
 
-Mandatory parameters: C<'Module::Name'>
+Mandatory parameters: C<'Module::Name'>. Note that this is one public method
+that takes its parameter in string format (as opposed to hash format).
 
 Returns an array reference containing the names of all subs found in the
 module's namespace symbol table.
